@@ -11,7 +11,9 @@ async def main() -> None:
     reddit = Reddit(APP_ID, APP_SECRET, USER_AGENT)
     # articles1 = await reddit.subreddit_articles("wow", 10, ArticlesSortType.HOT)
     # articles2 = await reddit.subreddit_articles("wow", 10, ArticlesSortType.RISING)
-    articles3 = await reddit.subreddit_article_comments("wow", "17tpwfa", 10, CommentsSortType.CONFIDENCE)
+    articles3 = await reddit.subreddit_article_comments(
+        "wow", "17tpwfa", 10, CommentsSortType.CONFIDENCE
+    )
     print()
 
 
